@@ -2,6 +2,8 @@ import time
 import dbus
 import glob
 import os
+import six
+import unittest
 import udiskstestcase
 
 
@@ -52,8 +54,8 @@ class UdisksDriveTest(udiskstestcase.UdisksTestCase):
 
         dev = self.get_device(self.vdevs[0])
         drive = self.get_drive(dev)
-        with self.assertRaisesRegex(dbus.exceptions.DBusException,
-                                    r'is not hot-pluggable device|is not ejectable device'):
+        with six.assertRaisesRegex(self, dbus.exceptions.DBusException,
+                                   r'is not hot-pluggable device|is not ejectable device'):
             drive.Eject(self.no_options)
 
         dev = self.get_device(self.cd_dev)
@@ -68,8 +70,8 @@ class UdisksDriveTest(udiskstestcase.UdisksTestCase):
 
             # check should fail since device cannot be powered off
             # sadly this is so far the only way we can test this function
-            with self.assertRaisesRegex(dbus.exceptions.DBusException,
-                                        'Failed: No usb device'):
+            with six.assertRaisesRegex(self, dbus.exceptions.DBusException,
+                                       'Failed: No usb device'):
                 drive.PowerOff(self.no_options)
 
     def test_30_setconfiguration(self):
@@ -95,8 +97,6 @@ class UdisksDriveTest(udiskstestcase.UdisksTestCase):
         ret_code, wwn = self.run_command('lsblk -d -no WWN %s' % self.cd_dev)
         self.assertEqual(ret_code, 0)
 
-        rotational = read_sys_file("block/%s/queue/rotational" % os.path.basename(self.cd_dev))
-
         # values expected are preset by scsi_debug and do not change
         expected_prop_vals = {
             'MediaCompatibility': ['optical_cd'],
@@ -106,7 +106,7 @@ class UdisksDriveTest(udiskstestcase.UdisksTestCase):
             'MediaRemovable': 1,
             'Optical': 1,
             'Removable': 1,
-            'RotationRate': -1 if rotational == "1" else 0,
+            'RotationRate': -1,
             'Media': 'optical_cd',
             'Model': read_sys_file('model'),
             'Revision': read_sys_file('rev'),
@@ -120,7 +120,7 @@ class UdisksDriveTest(udiskstestcase.UdisksTestCase):
 
         for prop_name, expected_val in expected_prop_vals.items():
             actual_val = self.get_property(self.cd_drive, '.Drive', prop_name)
-            actual_val.assertEqual(expected_val, msg=prop_name)
+            actual_val.assertEqual(expected_val)
 
         # timeDetected and TimeMediaDetected has the same value and SortKey value
         # is derived from it
